@@ -120,7 +120,7 @@ func runAttach(ctx context.Context) error {
 			return fmt.Errorf("list of machines could not be retrieved: %w", err)
 		}
 
-		members, err := flapsClient.List(ctx, "started")
+		members, err := flapsClient.ListActive(ctx)
 		if err != nil {
 			return fmt.Errorf("machines could not be retrieved %w", err)
 		}
